require("chartdirector")

class ClickpieController < ApplicationController
    include ChartDirector::InteractiveChartSupport

    def index()
        @ctrl_file = File.expand_path(__FILE__)

        # Get the selected year and month
        selectedYear = (params["year"]).to_i
        selectedMonth = (params["x"]).to_i + 1

        #
        # In this demo, we just split the monthly revenue into 3 parts using random
        # ratios. In real life, the data probably can come from a database based on
        # selectedYear and selectedMonth.
        #

        # Get the monthly revenue
        monthlyRevenue = (params["value"]).to_f

        # Split into 3 parts
        srand(selectedMonth * 2000 + selectedYear)
        data = Array.new(4)
        data[0] = (rand * 0.1 + 0.3) * monthlyRevenue
        data[1] = (rand * 0.1 + 0.2) * (monthlyRevenue - data[0])
        data[2] = (rand * 0.4 + 0.3) * (monthlyRevenue - data[0] - data[1])
        data[3] = monthlyRevenue - data[0] - data[1] - data[2]

        # The labels for the pie chart
        labels = ["Services", "Hardware", "Software", "Others"]

        # Create a PieChart object of size 600 x 240 pixels
        c = ChartDirector::PieChart.new(600, 280)

        # Set the center of the pie at (300, 140) and the radius to 120 pixels
        c.setPieSize(300, 140, 120)

        # Add a title to the pie chart using 18 pts Times Bold Italic font
        c.addTitle(sprintf("Revenue Breakdown for %s/%s", selectedMonth, selectedYear),
            "timesbi.ttf", 18)

        # Draw the pie in 3D with 20 pixels 3D depth
        c.set3D(20)

        # Set label format to display sector label, value and percentage in two lines
        c.setLabelFormat("{label}<*br*>${value|2}M ({percent}%)")

        # Set label style to 10 pts Arial Bold Italic font. Set background color to the
        # same as the sector color, with reduced-glare glass effect and rounded corners.
        t = c.setLabelStyle("arialbi.ttf", 10)
        t.setBackground(ChartDirector::SameAsMainColor, ChartDirector::Transparent,
            ChartDirector::glassEffect(ChartDirector::ReducedGlare))
        t.setRoundedCorners()

        # Use side label layout method
        c.setLabelLayout(ChartDirector::SideLayout)

        # Set the pie data and the pie labels
        c.setData(data, labels)

        # Create the image and save it in a temporary location
        session["chart1"] = c.makeChart2(ChartDirector::PNG)

        # Create an image map for the chart
        @imageMap = c.getHTMLImageMap(url_for(:controller => "piestub"), "",
            "title='{label}:US$ {value|2}M'")
    end

end
